@@ -9,7 +9,9 @@ bs <- c(
                       dir = "inst/docker/packages/")
 )
 
-built <- cr_build(cr_build_yaml(bs, timeout = 1200))
+build <- cr_build_yaml(bs, timeout = 2400)
+cr_build_write(build, "inst/docker/packages/cloudbuild.yml")
+# built <- cr_build(build)
 
-s_me <- cr_build_schedule_http(built)
-cr_schedule("packagetest-build", schedule = "15 9 * * 1", httpTarget = s_me)
+s_me <- cr_build_schedule_http(build)
+cr_schedule("packagetest-build2", schedule = "15 9 * * 1", httpTarget = s_me)
